@@ -371,7 +371,7 @@ class Item:
         single_page_keywords = single_page_keywords_default,
         next_page_keywords = next_page_keywords_default,
         page_template = None, allow_scripts = False, content_kwargs = None,
-        reformatter_url = None, downloader = None):
+        reformatter_url = None, downloader = None, ignore_images = False):
         """ It is clear that this is constructor :)
 
         Item is represented either by its content, when tag is specified, or by reference
@@ -389,6 +389,7 @@ class Item:
         reformatter_url - format string (%s is replaced with url from item).
         next_page_keywords - a list of names of links which leads to the next page of document if any
         single_page_keywords - a list of names of links which leads to the single page version
+        ignore_images - strip images from the item
         Used to process html document through online services such as Skweezer.
         """
         self.__url = url
@@ -396,7 +397,6 @@ class Item:
         self.__base = base
         self.__path = path
         self.__cache_path = cache_path
-        self.__allow_scripts = allow_scripts
         self.__page_template = page_template_default
         if page_template:
             self.__page_template = page_template
@@ -407,8 +407,12 @@ class Item:
         self.__attrs_for_fix = [("a", "href"), ("iframe", "src"), ("form", "action")]
         self.__attrs_for_cache = [("script", "src"), ("img", "src"), ("input", "src")]
         self.__tags_for_removal = ["object", "applet", "embed"]
+        self.__allow_scripts = allow_scripts
         if not self.__allow_scripts:
             self.__tags_for_removal.append("script")
+        self.__ignore_images = ignore_images
+        if self.__ignore_images:
+            self.__tags_for_removal.append("img")
         self.title = "untitled"
         self.__content_kwargs = content_kwargs
         self.__reformatter_url = reformatter_url
@@ -667,7 +671,7 @@ class Feed:
         next_page_keywords = next_page_keywords_default,
         delete_before_date = None, allow_scripts = False, inline_items = False, cache_items = False,
         include = None, exclude = None, content_kwargs = None, reformatter_url = None,
-        new_window = False, always_clear_cache = False):
+        new_window = False, always_clear_cache = False, ignore_images = False):
         """ Constructor.
 
         url - feed url.
@@ -692,6 +696,7 @@ class Feed:
         next_page_keywords - a list of names of links which leads to the next page of document if any
         single_page_keywords - a list of names of links which leads to the single page version
         new_window - True if you want all links in the feed to open new browser window.
+        ignore_images - True if you want to strip images from the feed (not articles)
         Used to process html document through online services such as Skweezer.
         """
         self.__url = url
@@ -719,6 +724,7 @@ class Feed:
         self.__cache_items = cache_items
         self.__delete_before_date = delete_before_date
         self.__allow_scripts = allow_scripts
+        self.__ignore_images = ignore_images
         self.__include = None
         if include:
             self.__include = re.compile(include)
@@ -796,7 +802,8 @@ class Feed:
         return True
 
 
-    def __create_feed_item(self, url = None, tag = None, base = None, path = None, cache_path = None):
+    def __create_feed_item(self, url = None, tag = None, base = None, path = None,
+        cache_path = None, ignore_images = False):
         """ This is just not to type all this code when you need new Item instance. """
         if path == None:
             path = self.__path
@@ -809,7 +816,7 @@ class Feed:
             next_page_keywords = self.__next_page_keywords,
             allow_scripts = self.__allow_scripts, content_kwargs = self.__content_kwargs,
             reformatter_url = self.__reformatter_url,
-            downloader = self.__downloader, page_template = self.__page_template)
+            downloader = self.__downloader, page_template = self.__page_template, ignore_images = ignore_images)
         
 
     def __get_update_html(self, html):
@@ -856,10 +863,11 @@ class Feed:
         item_a["href"] = link
         item_a.append(NavigableString(title))
         if self.__inline_items:
-            feed_item = self.__create_feed_item(url = link)
+            feed_item = self.__create_feed_item(url = link, ignore_images = self.__ignore_images)
             [item_div.append(t) for t in feed_item.process()]
         else:
-            feed_item = self.__create_feed_item(tag = self.__get_item_description(item), base = self._real_url)
+            feed_item = self.__create_feed_item(tag = self.__get_item_description(item),
+                base = self._real_url, ignore_images = self.__ignore_images)
             [item_div.append(t) for t in feed_item.process()]
             if self.__cache_items:
                 path = os.path.join(self.__path, self.__cache_path)
