@@ -20,7 +20,7 @@ import shutil
 import sys
 from BeautifulSoup import BeautifulStoneSoup
 
-version = "0.7.3"
+version = "0.7.4"
 feed_template_default = """
 <html>
     <head>
@@ -204,7 +204,8 @@ class FeedConfig:
 
     def __init__(self, cache_path, url, name, mode, icon_filename,
         days_to_keep = 7, include = "", exclude = "", message_count = 0,
-        content_tag = "", reformatter_url = "", checked = False, id = None,
+        content_tag = "", reformatter_url = "", checked = False,
+        ignore_images = False, id = None,
         print_version_keywords = feedcircuit.print_version_keywords_default,
         single_page_keywords = feedcircuit.single_page_keywords_default,
         next_page_keywords = feedcircuit.next_page_keywords_default):
@@ -225,6 +226,7 @@ class FeedConfig:
         self.print_version_keywords = print_version_keywords
         self.single_page_keywords = single_page_keywords
         self.next_page_keywords = next_page_keywords
+        self.ignore_images = ignore_images
         self.icon = None
         self.iter = None
         self.ord_num = 0
@@ -439,6 +441,7 @@ class FeedListModel(gtk.GenericTreeModel):
                     parser.get_default(section, "content tag", ""),
                     parser.get_default(section, "reformatter url", ""),
                     parser.getboolean_default(section, "checked", False),
+                    parser.getboolean_default(section, "ignore images", False),
                     section)
                 feed_config.ord_num = parser.getint_default(section, "order number", 0)
                 if parser.has_option(section, "print version keywords"):
@@ -483,6 +486,7 @@ class FeedListModel(gtk.GenericTreeModel):
                 parser.set(feed_config.id, "content tag", feed_config.content_tag)
                 parser.set(feed_config.id, "reformatter url", feed_config.reformatter_url)
                 parser.set(feed_config.id, "checked", str(feed_config.checked))
+                parser.set(feed_config.id, "ignore images", str(feed_config.ignore_images))
                 parser.set(feed_config.id, "order number", str(i))
                 parser.set(feed_config.id, "print version keywords", feed_config.get_print_version_keywords_string())
                 parser.set(feed_config.id, "single page keywords", feed_config.get_single_page_keywords_string())
@@ -805,8 +809,9 @@ class ExtraWindow(gtk.Dialog):
         self.include_entry = gtk.Entry()
         self.include_entry.set_width_chars(24)
         self.exclude_entry = gtk.Entry()
-        table = gtk.Table(rows = 4, columns = 2)
-        texts = [_("Days to keep"), _("Include urls"), _("Exclude urls") ]
+        self.ignore_images_check = gtk.CheckButton()
+        table = gtk.Table(rows = 5, columns = 2)
+        texts = [_("Days to keep"), _("Include urls"), _("Exclude urls"), _("Ignore images") ]
         for i in range(0, len(texts)):
             label = gtk.Label(texts[i])
             label.set_alignment(1, 0.5)
@@ -814,6 +819,7 @@ class ExtraWindow(gtk.Dialog):
         table.attach(self.days_editor, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
         table.attach(self.include_entry, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
         table.attach(self.exclude_entry, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
+        table.attach(self.ignore_images_check, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
         self.vbox.add(table)
         self.show_all()
 
@@ -874,6 +880,7 @@ class EditWindow(gtk.Dialog):
         self.print_version_keywords = feed_config.get_print_version_keywords_string()
         self.single_page_keywords = feed_config.get_single_page_keywords_string()
         self.next_page_keywords = feed_config.get_next_page_keywords_string()
+        self.ignore_images = feed_config.ignore_images
         hbox = gtk.HBox()
         self.url_entry = gtk.Entry()
         self.url_entry.set_width_chars(32)
@@ -929,6 +936,7 @@ class EditWindow(gtk.Dialog):
         self.feed_config.set_print_version_keywords_string(self.print_version_keywords)
         self.feed_config.set_single_page_keywords_string(self.single_page_keywords)
         self.feed_config.set_next_page_keywords_string(self.next_page_keywords)
+        self.feed_config.ignore_images = self.ignore_images
 
 
     def extra_clicked(self, source):
@@ -936,10 +944,12 @@ class EditWindow(gtk.Dialog):
         ext_window.days_editor.set_value(self.days_to_keep)
         ext_window.include_entry.set_text(self.include)
         ext_window.exclude_entry.set_text(self.exclude)
+        ext_window.ignore_images_check.set_active(self.ignore_images)
         if ext_window.run() == gtk.RESPONSE_ACCEPT:
             self.days_to_keep = ext_window.days_editor.get_value()
             self.include = ext_window.include_entry.get_text()
             self.exclude = ext_window.exclude_entry.get_text()
+            self.ignore_images = ext_window.ignore_images_check.get_active()
         ext_window.destroy()
 
 
@@ -1345,6 +1355,7 @@ class Program(hildon.Program):
                                 next_page_keywords = feed_config.next_page_keywords,
                                 reformatter_url = feed_config.reformatter_url,
                                 content_kwargs = feed_config.get_content_kwargs(),
+                                ignore_images = feed_config.ignore_images,
                                 new_window = self.__model.use_new_window,
                                 feed_item_template = item_t, feed_update_template = update_t,
                                 page_template = page_t, feed_template = feed_t)
@@ -1473,9 +1484,10 @@ class Program(hildon.Program):
             filename = os.path.join(from_path, feed_config.get_filename())
             if os.path.exists(filename):
                 shutil.move(filename, os.path.join(to_path, feed_config.get_filename()))
-            icon_path = os.path.join(from_path, feed_config.icon_filename)
-            if os.path.exists(icon_path):
-                shutil.move(icon_path, os.path.join(to_path, feed_config.icon_filename))
+            if feed_config.icon_filename:
+                icon_path = os.path.join(from_path, feed_config.icon_filename)
+                if os.path.exists(icon_path):
+                    shutil.move(icon_path, os.path.join(to_path, feed_config.icon_filename))
         dot_cache_path = os.path.join(from_path, ".cache")
         if os.path.exists(dot_cache_path):
             shutil.move(dot_cache_path, os.path.join(to_path, ".cache"))
